@@ -84,6 +84,7 @@ OC.L10N.register(
     "Yes" : "Ja",
     "No files in here" : "Keine Dateien vorhanden",
     "Choose" : "Auswählen",
+    "Copy" : "Kopieren",
     "Error loading file picker template: {error}" : "Fehler beim Laden der Dateiauswahlvorlage: {error}",
     "OK" : "OK",
     "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
@@ -130,7 +131,6 @@ OC.L10N.register(
     "Choose a password for the public link" : "Wähle ein Passwort für den öffentlichen Link",
     "Choose a password for the public link or press the \"Enter\" key" : "Wähle ein Passwort für die öffentliche Freigabe oder drücke \"Eingabe\"",
     "Copied!" : "Kopiert!",
-    "Copy" : "Kopieren",
     "Not supported!" : "Nicht unterstützt!",
     "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
     "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
@@ -219,8 +219,8 @@ OC.L10N.register(
     "The specified document has not been found on the server." : "Das ausgewählte Dokument wurde auf dem Server nicht gefunden.",
     "You can click here to return to %s." : "Hier klicken, um zu %s zurückzukehren.",
     "Internal Server Error" : "Interner Serverfehler",
-    "The server encountered an internal error and was unable to complete your request." : "Der Server hat einen internen Fehler und konnte Deine Anfrage nicht vervollständigen.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Bitte wende dich an den Serveradministrator, wenn dieser Fehler mehrfach auftritt, gebe bitte die, unten stehenden, technischen Details in Deinem Bericht mit an.",
+    "The server was unable to complete your request." : "Der Server konnte die Anfrage nicht fertig stellen.",
+    "If this happens again, please send the technical details below to the server administrator." : "Sollte dies erneut auftreten, sende die nachfolgenden technischen EInzelheiten bitte an Deinen Server-Administrator.",
     "More details can be found in the server log." : "Weitere Details können im Server-Protokoll gefunden werden.",
     "Technical details" : "Technische Details",
     "Remote Address: %s" : "Entfernte Adresse: %s",
@@ -271,7 +271,8 @@ OC.L10N.register(
     "Log in" : "Anmelden",
     "Stay logged in" : "Angemeldet bleiben",
     "Alternative Logins" : "Alternative Anmeldung",
-    "You are about to grant \"%s\" access to your %s account." : "Du bist dabei \"%s\" Zugriff auf Dein %s-Konto zu gewähren.",
+    "Account access" : "Konto Zugriff ",
+    "You are about to grant %s access to your %s account." : "Du bist dabei, %s Zugriff auf Dein %s-Konto zu gewähren.",
     "App token" : "App-Token",
     "Alternative login using app token" : "Alternative Anmeldung via App-Token",
     "Redirecting …" : "Weiterleiten…",
@@ -283,9 +284,9 @@ OC.L10N.register(
     "Cancel log in" : "Anmeldung abbrechen",
     "Use backup code" : "Backup-Code benutzen",
     "Error while validating your second factor" : "Fehler beim Bestätigen des zweiten Sicherheitsfaktors",
-    "You are accessing the server from an untrusted domain." : "Du greifst von einer nicht vertrauenswürdigen Domäne auf den Server zu.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktiere deinen Administrator. Wenn du Administrator dieser Instanz bist, konfiguriere die „trusted_domains“-Einstellung in config/config.php. Eine Beispielkonfiguration ist in config/config.sample.php verfügbar.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Deine Konfiguration zulässt, kannst Du als Administrator die folgende Schaltfläche benutzen, um diese Domain als vertrauenswürdig einzustufen.",
+    "Access through untrusted domain" : "Zugriff über eine nicht vertauenswürdige Domain",
+    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deinen Administrator. Wenn du Administrator bist,  bearbeite die „trusted_domains“-Einstellung in config/config.php wie in der Beispiels- config/config.sample.php.",
+    "Depending on your configuration, this button could also work to trust the domain:" : "Abhängig von Deiner Konfiguration kann diese Schaltfläche verwandt werden, um die Domain als vertrauenswürdig einzustufen:",
     "Add \"%s\" as trusted domain" : "„%s“ als vertrauenswürdige Domain hinzufügen",
     "App update required" : "App-Aktualisierung notwendig",
     "%s will be updated to version %s" : "%s wird auf Version %s aktualisiert",
@@ -335,11 +336,17 @@ OC.L10N.register(
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass %s %s mit Dir geteilt hat.\nZum Anzeigen: %s\n\n",
     "The share will expire on %s." : "Die Freigabe wird am %s ablaufen.",
     "Cheers!" : "Noch einen schönen Tag!",
+    "The server encountered an internal error and was unable to complete your request." : "Der Server hat einen internen Fehler und konnte Deine Anfrage nicht vervollständigen.",
+    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Bitte wende dich an den Serveradministrator, wenn dieser Fehler mehrfach auftritt, gebe bitte die, unten stehenden, technischen Details in Deinem Bericht mit an.",
     "Log out" : "Abmelden",
     "Use the following link to reset your password: {link}" : "Verwende den folgenden Link, um Dein Passwort zurückzusetzen: {link}",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass %s <strong>%s</strong> mit Dir geteilt hat.<br><a href=\"%s\">Sieh es Dir an!</a><br><br>",
     "This Nextcloud instance is currently in single user mode." : "Diese Nextcloud-Instanz befindet sich derzeit im Einzelbenutzermodus.",
     "This means only administrators can use the instance." : "Dies bedeutet, dass diese Instanz nur von Administratoren genutzt werden kann.",
-    "Please use the command line updater because you have a big instance." : "Da Du eine große Instanz nutzt, wird die Benutzung des Aktualisierungsprogrammes über die Kommandozeile empfohlen."
+    "You are accessing the server from an untrusted domain." : "Du greifst von einer nicht vertrauenswürdigen Domäne auf den Server zu.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Bitte kontaktiere deinen Administrator. Wenn du Administrator dieser Instanz bist, konfiguriere die „trusted_domains“-Einstellung in config/config.php. Eine Beispielkonfiguration ist in config/config.sample.php verfügbar.",
+    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Wenn es Deine Konfiguration zulässt, kannst Du als Administrator die folgende Schaltfläche benutzen, um diese Domain als vertrauenswürdig einzustufen.",
+    "Please use the command line updater because you have a big instance." : "Da Du eine große Instanz nutzt, wird die Benutzung des Aktualisierungsprogrammes über die Kommandozeile empfohlen.",
+    "You are about to grant \"%s\" access to your %s account." : "Du bist dabei \"%s\" Zugriff auf Dein %s-Konto zu gewähren."
 },
 "nplurals=2; plural=(n != 1);");
