@@ -3,8 +3,8 @@ OC.L10N.register(
     {
     "Please select a file." : "파일을 선택하십시오.",
     "File is too big" : "파일이 너무 큼",
-    "The selected file is not an image." : "선택한 파일은 이미지가 아님",
-    "The selected file cannot be read." : "선택한 파일을 읽을 수 없음",
+    "The selected file is not an image." : "선택한 파일은 사진이 아닙니다.",
+    "The selected file cannot be read." : "선택한 파일을 읽을 수 없습니다.",
     "Invalid file provided" : "잘못된 파일 지정됨",
     "No image or file provided" : "사진이나 파일이 없음",
     "Unknown filetype" : "알려지지 않은 파일 형식",
@@ -14,18 +14,23 @@ OC.L10N.register(
     "No crop data provided" : "선택된 데이터가 없습니다.",
     "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
     "Crop is not square" : "잘라내는 영역이 사각형이 아님",
+    "State token does not match" : "상태 토크인 일치하지 않음",
     "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
     "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
-    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "이 사용자 이름과 연결된 이메일 주소가 없어서 초기화 메일을 보낼 수 없습니다. 시스템 관리자에게 연락하십시오.",
+    "Password reset" : "암호 재설정",
+    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "아래 단추를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
+    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "아래 링크를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
+    "Reset your password" : "내 암호 재설정",
     "%s password reset" : "%s 암호 재설정",
-    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
+    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
+    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
     "Preparing update" : "업데이트 준비 중",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "수리 경고:",
     "Repair error: " : "수리 오류:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "자동 업데이트가 config.php를 비활성화하기 때문에 명령 줄 업데이트를 사용하십시오.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: %s 테이블 확인",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php에서 자동 업데이트가 비활성화되어 있기 때문에 명령줄 업데이트를 사용하십시오.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: 테이블 %s 확인 중",
     "Turned on maintenance mode" : "유지 보수 모드 켜짐",
     "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
     "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
@@ -45,26 +50,38 @@ OC.L10N.register(
     "%s (incompatible)" : "%s(호환 불가)",
     "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
     "Already up to date" : "최신 상태임",
+    "No contacts found" : "연락처를 찾을 수 없음",
+    "Show all contacts …" : "모든 연락처 보기 …",
+    "There was an error loading your contacts" : "연락처를 불러오는 중 오류가 발생했습니다",
+    "Loading your contacts …" : "연락처 불러오는 중 …",
+    "Looking for {term} …" : "{term} 검색 중 …",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">코드 무결성 검사 중 오류가 발생했습니다. 더 많은 정보를 보려면 누르십시오…</a>",
+    "No action available" : "사용할 수 있는 동작 없음",
+    "Error fetching contact actions" : "연락처 동작을 가져오는 중 오류 발생",
     "Settings" : "설정",
     "Connection to server lost" : "서버 연결이 끊어짐",
-    "Problem loading page, reloading in 5 seconds" : "페이지 로딩에 문제가 있습니다. 5초 후 다시로드 하십시오.",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["페이지 불러오기 오류, %n초 후 새로 고침"],
     "Saving..." : "저장 중...",
     "Dismiss" : "닫기",
+    "This action requires you to confirm your password" : "이 작업을 수행하려면 암호를 입력해야 합니다",
+    "Authentication required" : "인증 필요",
     "Password" : "암호",
     "Cancel" : "취소",
+    "Confirm" : "확인",
+    "Failed to authenticate, try again" : "인증할 수 없습니다. 다시 시도하십시오.",
     "seconds ago" : "초 지남",
-    "Logging in …" : "로그인 ...",
+    "Logging in …" : "로그인 중 …",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 포함하고 있는 이메일을 보냈습니다. 이메일이 도착하지 않은 경우 스팸함을 확인해 보십시오.<br>스팸함에도 없는 경우 로컬 관리자에게 문의하십시오.",
-    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "파일이 암호화되어 있습니다. 복구 키를 활성화하지 않았다면 암호를 초기화한 후 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 계속하기 전에 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 암호를 초기화하면 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 시스템 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
     "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
     "Password can not be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
     "No" : "아니요",
     "Yes" : "예",
     "No files in here" : "여기에 파일이 없음",
     "Choose" : "선택",
+    "Copy" : "복사",
     "Error loading file picker template: {error}" : "파일 선택 템플릿을 불러오는 중 오류 발생: {error}",
-    "Ok" : "확인",
+    "OK" : "확인",
     "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
     "read-only" : "읽기 전용",
     "_{count} file conflict_::_{count} file conflicts_" : ["파일 {count}개 충돌"],
@@ -72,7 +89,7 @@ OC.L10N.register(
     "New Files" : "새 파일",
     "Already existing files" : "파일이 이미 존재합니다",
     "Which files do you want to keep?" : "어느 파일을 유지하시겠습니까?",
-    "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면, 파일 이름에 번호가 추가될 것입니다.",
+    "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면, 복사된 파일 이름에 번호가 추가됩니다.",
     "Continue" : "계속",
     "(all selected)" : "(모두 선택됨)",
     "({count} selected)" : "({count}개 선택됨)",
@@ -84,51 +101,78 @@ OC.L10N.register(
     "Good password" : "좋은 암호",
     "Strong password" : "강력한 암호",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "WebDAV 서비스가 올바르게 작동하지 않아서 웹 서버에서 파일 동기화를 사용할 수 없습니다.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "일부 파일에 대한 무결성 검사를 통과하지 않았습니다. 이 문제를 해결하는 방법에 대한 자세한 내용은 우리의 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>에서 찾을 수 있습니다. (<a href=\"{codeIntegrityDownloadEndpoint}\">잘못된 파일 목록...</a> / <a href=\"{rescanEndpoint}\">재검색...</a>)",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "웹 서버가 \"{url}\"을 올바르게 처리할 수 있도록 설정되어 있지 않습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>를 참고하십시오.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "서버에서 인터넷 연결을 사용할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 제 3자 앱 설치 등 기능을 사용할 수 없습니다. 원격에서 파일에 접근하거나, 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 인터넷에 연결하는 것을 추천합니다.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "메모리 캐시가 구성되지 않았습니다. 가능한 경우 memcache를 설정하여 성능을 향상시킬 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>를 참고하십시오.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP가 안전한 난수 발생기(/dev/urandom)를 사용할 수 없어 보안에 취약합니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>를 참고하십시오.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "현재 PHP {version}을(를) 사용하고 있습니다. 배포판에서 지원하는 대로 PHP 버전을 업그레이드하여 <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">PHP 그룹에서 제공하는 성능 및 보안 업데이트</a>를 받는 것을 추천합니다.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If you are not accessing Nextcloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to Nextcloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "역방향 프록시 헤더 설정이 올바르지 않거나 신뢰하는 프록시를 통해 Nextcloud에 접근하고 있을 수 있습니다. 만약 Nextcloud를 신뢰하는 프록시를 통해 접근하고 있지 않다면 이는 보안 문제이며 공격자가 IP 주소를 속이고 있을 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>를 참고하십시오.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 \"memcache\"가 설치되어 있습니다. \\OC\\Memcache\\Memcached는 \"memcache\"가 아닌 \"memcached\"만 지원합니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">이 두 모듈에 대한 memcached 위키</a>를 참고하십시오.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "일부 파일이 무결성 검사를 통과하지 못습니다. 이 문제를 해결하는 방법은 <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">문서</a>를 참고하십시오.(<a href=\"{codeIntegrityDownloadEndpoint}\">잘못된 파일 목록…</a> / <a href=\"{rescanEndpoint}\">다시 검색…</a>)",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. We strongly recommend enabling this function." : "PHP 함수 \"set_time_limit\"을(를) 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
     "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "인터넷에서 데이터 디렉터리와 파일에 접근할 수 있습니다. .htaccess 파일이 작동하지 않습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 직접 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 경로 바깥에 두십시오.",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "데이터 디렉터리와 파일을 인터넷에서 접근할 수 있는 것 같습니다. .htaccess 파일을 사용할 수 없습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 디렉터리 밖으로 옮기는 것을 추천합니다.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 헤더가 \"{expected}\"와(과) 같이 설정되지 않았습니다. 잠재적인 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "\"엄격한 - 전송 보안\" HTTP 헤더에 적어도 \"{seconds}\"초로 설정되어 있지 않습니다. <a href=\"{docUrl}\" rel=\"noreferrer\">보안 팁</a>에 언급 된 바와 같이 보안을 강화하기 위해, HSTS를 사용하는 것이 좋습니다.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "\"Strict-Transport-Security\" HTTP 헤더가 \"{seconds}\"초 이상로 설정되어 있지 않습니다. <a href=\"{docUrl}\" rel=\"noreferrer\">보안 팁</a>에서 제안하는 것처럼 HSTS를 활성화하는 것을 추천합니다.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "이 사이트를 HTTP로 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁</a>에 나타난 것처럼 서버 설정을 변경하여 HTTPS를 사용하는 것을 강력히 추천합니다.",
     "Shared" : "공유됨",
     "Shared with {recipients}" : "{recipients} 님과 공유됨",
-    "Error" : "오류",
-    "Error while sharing" : "공유하는 중 오류 발생",
-    "Error while unsharing" : "공유 해제하는 중 오류 발생",
     "Error setting expiration date" : "만료 날짜 설정 오류",
     "The public link will expire no later than {days} days after it is created" : "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
     "Set expiration date" : "만료 날짜 설정",
     "Expiration" : "만료",
     "Expiration date" : "만료 날짜",
     "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
-    "Copied!" : "복사됨!",
+    "Copied!" : "복사 성공!",
     "Not supported!" : "지원하지 않음!",
-    "Press ⌘-C to copy." : "⌘-C 복사",
-    "Press Ctrl-C to copy." : "Ctrl-C 복사",
+    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
+    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
     "Resharing is not allowed" : "다시 공유할 수 없습니다",
+    "Share to {name}" : "{name} 님에게 공유",
     "Share link" : "링크 공유",
     "Link" : "링크",
     "Password protect" : "암호 보호",
-    "Allow upload and editing" : "업로드 및 편집 허용",
+    "Allow editing" : "편집 허용",
     "Email link to person" : "이메일 주소",
     "Send" : "전송",
+    "Allow upload and editing" : "업로드 및 편집 허용",
+    "File drop (upload only)" : "파일 보관소(업로드만 허용)",
     "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
     "Shared with you by {owner}" : "{owner} 님이 공유 중",
-    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} 링크를 통해 공유",
+    "Choose a password for the mail share" : "이메일 공유 암호 입력",
+    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} 님이 링크를 통해 공유",
     "group" : "그룹",
     "remote" : "원격",
+    "email" : "이메일",
+    "shared by {sharer}" : "{sharer} 님이 공유함",
     "Unshare" : "공유 해제",
-    "can reshare" : "재공유 가능",
-    "can edit" : "편집 가능",
-    "access control" : "접근 제어",
+    "Can reshare" : "재공유 가능",
+    "Can edit" : "편집 가능",
+    "Can create" : "생성 가능",
+    "Can change" : "변경 가능",
+    "Can delete" : "삭제 가능",
+    "Access control" : "접근 제어",
     "Could not unshare" : "공유 해제할 수 없음",
+    "Error while sharing" : "공유하는 중 오류 발생",
     "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
-    "No users or groups found for {search}" : "{search}에 해당하는 사용자나 그룹을 찾을 수 없음",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["자동 완성을 시작하려면 최소 {count}글자를 입력해야 합니다"],
+    "This list is maybe truncated - please refine your search term to see more results." : "결과 목록이 잘렸을 수도 있습니다. 검색할 단어를 더 정확히 입력해서 더 많은 결과를 보십시오.",
+    "No users or groups found for {search}" : "{search} 사용자나 그룹을 찾을 수 없음",
     "No users found for {search}" : "{search} 사용자를 찾을 수 없음",
     "An error occurred. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
     "{sharee} (group)" : "{sharee}(그룹)",
     "{sharee} (remote)" : "{sharee}(원격)",
+    "{sharee} (email)" : "{sharee}(이메일)",
+    "{sharee} ({type}, {owner})" : "{sharee}({type}, {owner})",
     "Share" : "공유",
+    "Share with other people by entering a user or group, a federated cloud ID or an email address." : "사용자나 그룹 이름, 연합 클라우드 ID 및 이메일 주소를 입력해서 다른 사람과 공유하십시오.",
+    "Share with other people by entering a user or group or a federated cloud ID." : "사용자나 그룹 이름, 연합 클라우드 ID를 입력해서 다른 사람과 공유하십시오.",
+    "Share with other people by entering a user or group or an email address." : "사용자나 그룹 이름 및 이메일 주소를 입력해서 다른 사람과 공유하십시오.",
+    "Name or email address..." : "이름이나 이메일 주소...",
+    "Name or federated cloud ID..." : "이름이나 연합 클라우드 ID...",
+    "Name, federated cloud ID or email address..." : "이름, 연합 클라우드 ID 및 이메일 주소...",
+    "Name..." : "이름...",
+    "Error" : "오류",
     "Error removing share" : "공유 삭제 중 오류 발생",
     "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
     "restricted" : "제한됨",
@@ -137,27 +181,25 @@ OC.L10N.register(
     "Delete" : "삭제",
     "Rename" : "이름 바꾸기",
     "Collaborative tags" : "협동 태그",
-    "The object type is not specified." : "객체 유형이 지정되지 않았습니다.",
-    "Enter new" : "새로운 값 입력",
-    "Add" : "추가",
-    "Edit tags" : "태그 편집",
-    "Error loading dialog template: {error}" : "대화 상자 템플릿을 불러오는 중 오류 발생: {error}",
-    "No tags selected for deletion." : "삭제할 태그를 선택하지 않았습니다.",
+    "No tags found" : "태그를 찾을 수 없음",
     "unknown text" : "알 수 없는 텍스트",
     "Hello world!" : "Hello world!",
     "sunny" : "맑음",
     "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
     "Hello {name}" : "{name} 님 안녕하세요",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>검색 결과입니다<script>alert(1)</script></strong>",
     "new" : "새로운 항목",
     "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "업데이트 중입니다. 일부 환경에서 이 페이지를 닫을 경우 작업이 중단될 수 있습니다.",
     "Update to {version}" : "{version}(으)로 업데이트",
     "An error occurred." : "오류가 발생했습니다.",
     "Please reload the page." : "페이지를 새로 고치십시오.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "업데이트에 실패했습니다. 더 많은 정보를 보려면 이 문제를 다루은 <a href=\"{url}\">포럼 글</a>을 참조하십시오.",
-    "Continue to Nextcloud" : "Nextcloud 계속",
-    "The update was successful. Redirecting you to Nextcloud now." : "업데이트가 성공했습니다. 지금 Nextcloud로 리디렉션합니다.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "업데이트에 실패했습니다. 더 많은 정보를 보려면 이 문제에 대한 <a href=\"{url}\">포럼 글</a>을 참조하십시오.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "업데이트가 실패했습니다. 이 문제를 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 커뮤니티</a>에 보고하여 주십시오.",
+    "Continue to Nextcloud" : "Nextcloud로 계속 진행",
+    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["업데이트가 성공했습니다. %n초 후 Nextcloud로 이동합니다."],
     "Searching other places" : "다른 장소 찾는 중",
-    "No search results in other folders for '{tag}{filter}{endtag}'" : "폴더의 검색 결과 없음 '{tag}{filter}{endtag}'",
+    "No search results in other folders for {tag}{filter}{endtag}" : "다른 폴더에 {tag}{filter}{endtag} 검색 결과가 없음",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["다른 폴더의 검색 결과 {count}개"],
     "Personal" : "개인",
     "Users" : "사용자",
@@ -168,12 +210,7 @@ OC.L10N.register(
     "File not found" : "파일을 찾을 수 없음",
     "The specified document has not been found on the server." : "지정한 문서를 서버에서 찾을 수 없습니다.",
     "You can click here to return to %s." : "%s(으)로 돌아가려면 여기를 누르십시오.",
-    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "안녕하세요,\n\n%s 님이 %s을(를) 공유하였음을 알려 드립니다.\n보기 링크: %s\n\n",
-    "The share will expire on %s." : "이 공유는 %s 까지 유지됩니다.",
-    "Cheers!" : "감사합니다!",
     "Internal Server Error" : "내부 서버 오류",
-    "The server encountered an internal error and was unable to complete your request." : "서버에 내부 오류가 발생하여 요청을 처리할 수 없었습니다.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "이 오류가 여러 번 발생한다면 서버 관리자에게 연락해 주시고, 아래 기술적인 정보를 포함해 주십시오.",
     "More details can be found in the server log." : "서버 로그에서 자세한 정보를 찾을 수 있습니다.",
     "Technical details" : "기술 정보",
     "Remote Address: %s" : "원격 주소: %s",
@@ -185,14 +222,14 @@ OC.L10N.register(
     "Line: %s" : "줄: %s",
     "Trace" : "추적",
     "Security warning" : "보안 경고",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수 없을 수도 있습니다.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "올바르게 서버를 구성하는 방법에 대한 자세한 내용은 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">설명서</a>를 참조하시기 바랍니다.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "서버를 올바르게 설정하는 방법에 대해서 더 알아보려면 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">문서</a>를 참조하십시오.",
     "Create an <strong>admin account</strong>" : "<strong>관리자 계정</strong> 만들기",
     "Username" : "사용자 이름",
     "Storage & database" : "저장소 및 데이터베이스",
     "Data folder" : "데이터 폴더",
     "Configure the database" : "데이터베이스 설정",
-    "Only %s is available." : "%s만 사용 가능합니다.",
+    "Only %s is available." : "%s만 사용할 수 있습니다.",
     "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
     "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
     "Database user" : "데이터베이스 사용자",
@@ -200,17 +237,20 @@ OC.L10N.register(
     "Database name" : "데이터베이스 이름",
     "Database tablespace" : "데이터베이스 테이블 공간",
     "Database host" : "데이터베이스 호스트",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
     "Performance warning" : "성능 경고",
-    "SQLite will be used as database." : "데이터베이스로 SQLite를 사용하게 됩니다.",
-    "For larger installations we recommend to choose a different database backend." : "대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드를 선택할 것을 권장합니다.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정일 때는, SQLite를 사용하지 않는 것이 좋습니다.",
+    "SQLite will be used as database." : "데이터베이스로 SQLite를 사용할 것입니다.",
+    "For larger installations we recommend to choose a different database backend." : "대규모 파일을 관리하려고 한다면 다른 데이터베이스 백엔드를 선택할 것을 권장합니다.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면 SQLite를 사용하지 않는 것이 좋습니다.",
     "Finish setup" : "설치 완료",
-    "Finishing …" : "완료 중 ...",
+    "Finishing …" : "완료 중 …",
     "Need help?" : "도움이 필요한가요?",
     "See the documentation" : "문서 보기",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 JavaScript가 필요합니다. {linkstart}JavaScript를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
-    "Log out" : "로그아웃",
+    "More apps" : "더 많은 앱",
     "Search" : "검색",
+    "This action requires you to confirm your password:" : "이 작업을 수행하려면 암호를 입력해야 합니다:",
+    "Confirm your password" : "암호를 입력하십시오",
     "Server side authentication failed!" : "서버 인증 실패!",
     "Please contact your administrator." : "관리자에게 문의하십시오.",
     "An internal error occurred." : "내부 오류가 발생했습니다.",
@@ -221,22 +261,17 @@ OC.L10N.register(
     "Log in" : "로그인",
     "Stay logged in" : "로그인 유지",
     "Alternative Logins" : "대체 로그인",
-    "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
+    "App token" : "앱 토큰",
+    "Alternative login using app token" : "앱 토큰을 사용한 대체 로그인",
+    "Redirecting …" : "전환 중 …",
     "New password" : "새 암호",
     "New Password" : "새 암호",
     "Reset password" : "암호 재설정",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "안녕하세요,<br><br>%s 님이 <strong>%s</strong>을(를) 공유하였음을 알려 드립니다.<br><a href=\"%s\">보러 가기!</a><br><br>",
-    "This Nextcloud instance is currently in single user mode." : "Nextcloud 인스턴스가 현재 단일 사용자 모드로 동작 중입니다.",
-    "This means only administrators can use the instance." : "현재 시스템 관리자만 인스턴스를 사용할 수 있습니다.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나, 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오",
-    "Thank you for your patience." : "기다려 주셔서 감사합니다.",
-    "Two-factor authentication" : "이중 인증",
-    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "강화 된 보안 계정을 사용할 수 있습니다. 두 번째 인자를 사용하여 인증하시기 바랍니다.",
+    "Two-factor authentication" : "2단계 인증",
+    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "현재 계정에 향상된 보안이 켜져 있습니다. 2단계 인증으로 인증하십시오.",
     "Cancel log in" : "로그인 취소",
     "Use backup code" : "백업 코드 사용",
-    "You are accessing the server from an untrusted domain." : "신뢰할 수 없는 도메인으로 서버에 접근하고 있습니다.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 이 인스턴스의 관리자라면 config/config.php에서 \"trusted_domains\" 설정을 편집하십시오. config/config.sample.php에 있는 예제 설정을 참고하십시오.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "설정에 따라서 관리자 권한으로 아래 단추를 눌러서 이 도메인을 신뢰하도록 설정할 수 있습니다.",
+    "Error while validating your second factor" : "2단계 인증을 검증하는 중 오류 발생",
     "Add \"%s\" as trusted domain" : "\"%s\"을(를) 신뢰할 수 있는 도메인으로 추가",
     "App update required" : "앱 업데이트 필요",
     "%s will be updated to version %s" : "%s 앱을 버전 %s(으)로 업데이트합니다",
@@ -248,97 +283,52 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "큰 파일을 설치하는 경우 시간이 초과될 수 있으므로, 설치 디렉터리에서 다음 명령을 실행하셔도 됩니다:",
     "Detailed logs" : "자세한 로그",
     "Update needed" : "업데이트 필요",
-    "Please use the command line updater because you have a big instance." : "당신은 큰 인스턴스를 가지고 있기 때문에 명령 행 업데이트를 사용하십시오.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "도움이 필요한 경우 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">문서</a>를 참조하십시오.",
     "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
     "This page will refresh itself when the %s instance is available again." : "%s 인스턴스를 다시 사용할 수 있으면 자동으로 새로 고칩니다.",
-    "Error loading tags" : "태그 불러오기 오류",
-    "Tag already exists" : "태그가 이미 존재합니다",
-    "Error deleting tag(s)" : "태그 삭제 오류",
-    "Error tagging" : "태그 추가 오류",
-    "Error untagging" : "태그 해제 오류",
-    "Error favoriting" : "즐겨찾기 추가 오류",
-    "Error unfavoriting" : "즐겨찾기 삭제 오류",
-    "Couldn't send mail to following users: %s " : "%s 님에게 메일을 보낼 수 없습니다.",
-    "Sunday" : "일요일",
-    "Monday" : "월요일",
-    "Tuesday" : "화요일",
-    "Wednesday" : "수요일",
-    "Thursday" : "목요일",
-    "Friday" : "금요일",
-    "Saturday" : "토요일",
-    "Sun." : "일",
-    "Mon." : "월",
-    "Tue." : "화",
-    "Wed." : "수",
-    "Thu." : "목",
-    "Fri." : "금",
-    "Sat." : "토",
-    "Su" : "일",
-    "Mo" : "월",
-    "Tu" : "화",
-    "We" : "수",
-    "Th" : "목",
-    "Fr" : "금",
-    "Sa" : "토",
-    "January" : "1월",
-    "February" : "2월",
-    "March" : "3월",
-    "April" : "4월",
-    "May" : "5월",
-    "June" : "6월",
-    "July" : "7월",
-    "August" : "8월",
-    "September" : "9월",
-    "October" : "10월",
-    "November" : "11월",
-    "December" : "12월",
-    "Jan." : "1월",
-    "Feb." : "2월",
-    "Mar." : "3월",
-    "Apr." : "4월",
-    "May." : "5월",
-    "Jun." : "6월",
-    "Jul." : "7월",
-    "Aug." : "8월",
-    "Sep." : "9월",
-    "Oct." : "10월",
-    "Nov." : "11월",
-    "Dec." : "12월",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "서버에서 인터넷 연결을 사용할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 제 3자 앱 설치 등 기능을 사용할 수 없습니다. 원격에서 파일에 접근하거나, 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 인터넷에 연결하는 것을 추천합니다.",
-    "Allow editing" : "편집 허용",
-    "Hide file listing" : "숨김 파일 목록",
-    "Sending ..." : "전송 중...",
-    "Email sent" : "이메일 발송됨",
-    "Send link via email" : "이메일로 링크 보내기",
-    "notify by email" : "이메일로 알림",
-    "can share" : "공유 가능",
-    "create" : "생성",
-    "change" : "변경",
-    "delete" : "삭제",
-    "{sharee} (at {server})" : "{sharee}({server}에 있음)",
-    "Share with users…" : "사용자와 공유 ...",
-    "Share with users, groups or remote users…" : "사용자, 그룹 또는 원격 사용자와 공유 ...",
-    "Share with users or groups…" : "사용자 또는 그룹과 공유 ...",
-    "Share with users or remote users…" : "원격 사용자에 대한 사용자와 공유 ...",
-    "Warning" : "경고",
-    "Error while sending notification" : "알림을 보내는 중 오류 발생",
-    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "업그레이드 중입니다. 이 페이지를 열어 두면 일부 환경에서 진행 과정을 중단시킬 수 있습니다.",
-    "Updating to {version}" : "{version}(으)로 업데이트 중",
-    "The update was successful. There were warnings." : "업데이트가 성공했습니다. 일부 경고가 있습니다.",
-    "No search results in other folders" : "다른 폴더에 검색 결과 없음",
-    "Two-step verification" : "2단계 인증",
-    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "강화된 보안 계정을 사용할 수 있습니다. 두 번째 인자를 사용하여 인증하시기 바랍니다.",
-    "Cancel login" : "로그인 취소",
-    "Please authenticate using the selected factor." : "선택한 요소를 사용하여 인증하시기 바랍니다.",
-    "An error occured while verifying the token" : "토큰을 확인하는 중 오류 발생",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "일부 파일에 대한 무결성 검사를 통과하지 않았습니다. 이 문제를 해결하는 방법에 대한 자세한 내용은 우리의 <a target=\"_blank\" href=\"{docLink}\">문서</a>에서 찾을 수 있습니다. (<a href=\"{codeIntegrityDownloadEndpoint}\">잘못된 파일 목록...</a> / <a href=\"{rescanEndpoint}\">재검색...</a>)",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"엄격한 - 전송 보안\" HTTP 헤더에 적어도 \"{seconds}\"초로 설정되어 있지 않습니다. <a href=\"{docUrl}\">보안 팁</a>에 언급 된 바와 같이 보안을 강화하기 위해, HSTS를 사용하는 것이 좋습니다.",
-    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "username@example.com/nextcloud 형식으로 다른 nextcloud 사용자와 공유할 수 있습니다",
-    "not assignable" : "할당할 수 없음",
-    "Updating {productName} to version {version}, this may take a while." : "{productName} 버전 {version}(으)로 업데이트 중 입니다. 시간이 다소 걸릴 수 있습니다.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "서버를 올바르게 구성하는 방법에 대한 자세한 내용은 <a href=\"%s\" target=\"_blank\">설명서</a>를 참조하시기 바랍니다.",
-    "An internal error occured." : "내부 오류가 발생했습니다."
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나, 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
+    "Thank you for your patience." : "기다려 주셔서 감사합니다.",
+    "Problem loading page, reloading in 5 seconds" : "페이지 불러오기 오류, 5초 후 새로 고침",
+    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 복구 키를 활성화하지 않았다면 암호를 초기화한 후 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 계속하기 전에 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
+    "Ok" : "확인",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "인터넷에서 데이터 디렉터리와 파일에 접근할 수 있습니다. .htaccess 파일이 작동하지 않습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 직접 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 경로 바깥에 두십시오.",
+    "Error while unsharing" : "공유 해제하는 중 오류 발생",
+    "can reshare" : "재공유 가능",
+    "can edit" : "편집 가능",
+    "can create" : "생성 가능",
+    "can change" : "변경 가능",
+    "can delete" : "삭제 가능",
+    "access control" : "접근 제어",
+    "Share with people on other servers using their Federated Cloud ID username@example.com/nextcloud" : "연합 클라우드 ID를 통하여 다른 서버의 사람과 공유 username@example.com/cloud",
+    "Share with users or by mail..." : "사용자 및 이메일로 공유...",
+    "Share with users or remote users..." : "사용자 및 원격 사용자와 공유...",
+    "Share with users, remote users or by mail..." : "사용자, 원격 사용자 및 이메일로 공유...",
+    "Share with users or groups..." : "사용자 및 그룹과 공유...",
+    "Share with users, groups or by mail..." : "사용자, 그룹 및 이메일로 공유...",
+    "Share with users, groups or remote users..." : "사용자, 그룹 및 원격 사용자와 공유...",
+    "Share with users, groups, remote users or by mail..." : "사용자, 그룹, 원격 사용자나 이메일로 공유...",
+    "Share with users..." : "사용자와 공유...",
+    "The object type is not specified." : "객체 유형이 지정되지 않았습니다.",
+    "Enter new" : "새로운 값 입력",
+    "Add" : "추가",
+    "Edit tags" : "태그 편집",
+    "Error loading dialog template: {error}" : "대화 상자 템플릿을 불러오는 중 오류 발생: {error}",
+    "No tags selected for deletion." : "삭제할 태그를 선택하지 않았습니다.",
+    "The update was successful. Redirecting you to Nextcloud now." : "업데이트가 성공했습니다. 지금 Nextcloud로 이동합니다.",
+    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "안녕하세요,\n\n%s 님이 %s을(를) 공유하였음을 알려 드립니다.\n보기 링크: %s\n\n",
+    "The share will expire on %s." : "이 공유는 %s에 만료됩니다.",
+    "Cheers!" : "감사합니다!",
+    "The server encountered an internal error and was unable to complete your request." : "서버에 내부 오류가 발생하여 요청을 처리할 수 없었습니다.",
+    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "이 오류가 여러 번 발생한다면 서버 관리자에게 연락해 주시고, 아래 기술적인 정보를 포함해 주십시오.",
+    "Log out" : "로그아웃",
+    "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "안녕하세요,<br><br>%s 님이 <strong>%s</strong>을(를) 공유하였음을 알려 드립니다.<br><a href=\"%s\">보러 가기!</a><br><br>",
+    "This Nextcloud instance is currently in single user mode." : "Nextcloud 인스턴스가 현재 단일 사용자 모드로 동작 중입니다.",
+    "This means only administrators can use the instance." : "현재 시스템 관리자만 인스턴스를 사용할 수 있습니다.",
+    "You are accessing the server from an untrusted domain." : "신뢰할 수 없는 도메인으로 서버에 접근하고 있습니다.",
+    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 이 인스턴스의 관리자라면 config/config.php에서 \"trusted_domains\" 설정을 편집하십시오. config/config.sample.php에 있는 예제 설정을 참고하십시오.",
+    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "설정에 따라서 관리자 권한으로 아래 단추를 눌러서 이 도메인을 신뢰하도록 설정할 수 있습니다.",
+    "Please use the command line updater because you have a big instance." : "현재 인스턴스 크기가 크기 때문에 명령행 업데이터를 사용하십시오.",
+    "You are about to grant \"%s\" access to your %s account." : "\"%s\"에 접근하기 위해서 %s 계정을 사용하려고 합니다."
 },
 "nplurals=1; plural=0;");
