@@ -1,47 +1,108 @@
 OC.L10N.register(
     "settings",
     {
+    "{actor} changed your password" : "{actor} је променио Вашу лозинку",
+    "You changed your password" : "Променили сте лозинку",
+    "Your password was reset by an administrator" : "Администратор је ресетовао Вашу лозинку",
+    "{actor} changed your email address" : "{actor} је изменио адресу Ваше е-поште",
+    "You changed your email address" : "Променили сте адресу е-поште",
+    "Your email address was changed by an administrator" : "Администратор је изменио адресу Ваше е-поште",
+    "Security" : "Безбедност",
+    "You successfully logged in using two-factor authentication (%1$s)" : "Успешно сте се пријавили са двофакторском провером идентитета (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "Пријава са двофакторском провером идентитета неуспела (%1$s)",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваша <strong>лозинка</strong> или <strong>адреса е-поште</strong> је измењена",
+    "Your apps" : "Ваше апликације",
+    "Enabled apps" : "Укључене апликације",
+    "Disabled apps" : "Искључене апликације",
+    "App bundles" : "Пакети апликација",
     "Wrong password" : "Погрешна лозинка",
     "Saved" : "Сачувано",
     "No user supplied" : "Није наведен корисник",
     "Unable to change password" : "Не могу да променим лозинку",
     "Authentication error" : "Грешка при провери идентитета",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Наведите администраторску лозинку опоравка; у супротном, сви кориснички подаци биће изгубљени.",
     "Wrong admin recovery password. Please check the password and try again." : "Погрешна администраторска лозинка опоравка. Проверите лозинку и покушајте поново.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Позадина не подржава измену лозинке, али кориснички кључеви за шифровање су успешно ажурирани.",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "Инсталирање и ажурирање апликација кроз продавницу или здруженом дељењу у облаку",
     "Federated Cloud Sharing" : "Здружено дељење у облаку",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL користи застарелу верзију %s (%s). Ажурирајте оперативни систем или функционалности као што је %s неће радити поуздано.",
     "A problem occurred, please check your log files (Error: %s)" : "Појавио се проблем. Проверите записнике (грешка: %s)",
     "Migration Completed" : "Пресељење завршено",
     "Group already exists." : "Група већ постоји.",
     "Unable to add group." : "Није могуће додати групу.",
     "Unable to delete group." : "Није могуће обрисати групу.",
+    "Invalid SMTP password." : "Неисправна SMTP лозинка.",
+    "Well done, %s!" : "Свака част, %s!",
+    "If you received this email, the email configuration seems to be correct." : "Ако добијате ову е-пошту, подешавања е-поште су вам исправна.",
+    "Email setting test" : "Тестирај поставке е-поште",
+    "Email could not be sent. Check your mail server log" : "Не могу да пошаљем Е-пошта. Погледајте записнике сервера е-поште",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Појавио се проблем приликом слања е-поште. Проверите ваше поставке. (Грешка: %s)",
     "You need to set your user email before being able to send test emails." : "Морате поставити адресу е-поште пре слања тестне поруке.",
     "Invalid mail address" : "Неисправна е-адреса",
+    "No valid group selected" : "Није изабрана ниједна исправна група",
     "A user with that name already exists." : "Корисник са тим именом већ постоји.",
+    "To send a password link to the user an email address is required." : "Да бисте кориснику послали везу ка лозинци. потребна је адреса е-поште.",
     "Unable to create user." : "Не могу да направим корисника.",
     "Unable to delete user." : "Не могу да обришем корисника.",
+    "Error while enabling user." : "Грешка при омогућавању корисника.",
+    "Error while disabling user." : "Грешка при онемогућавању корисника",
+    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Да бисте верификовали Ваш Твитер налог, окачите следећи твит (пазите само да не преламате редове у твиту):",
+    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Да бисте верификовали веб сајт, поставите следећи садржај у корени директоријум веб сајта на '.well-known/CloudIdVerificationCode.txt' (пазите само да је цео текст у једној линији):",
+    "Settings saved" : "Подешавања сачувана",
     "Unable to change full name" : "Не могу да променим пуно име",
+    "Unable to change email address" : "Не могу да изменим адресу е-поште",
     "Your full name has been changed." : "Ваше пуно име је промењено.",
     "Forbidden" : "Забрањено",
     "Invalid user" : "Неисправан корисник",
-    "Unable to change mail address" : "Не могу да изменим е-адресу",
-    "Email saved" : "Е-порука сачувана",
+    "Unable to change mail address" : "Не могу да изменим адресу е-поште",
+    "Email saved" : "Адреса е-поште сачувана",
+    "%1$s changed your password on %2$s." : "%1$s је изменио Вашу лозинку на %2$s.",
+    "Your password on %s was changed." : "Ваша лозинка на %s је измењена.",
+    "Your password on %s was reset by an administrator." : "Администратор на %s је ресетовао Вашу лозинку.",
+    "Password changed for %s" : "Лозинка на %s промењена.",
+    "If you did not request this, please contact an administrator." : "Ако нисте Ви ово захтевали, контактирајте администратора.",
+    "Password for %1$s changed on %2$s" : "Лозинка за %1$s промењена на %2$s",
+    "%1$s changed your email address on %2$s." : "%1$s је изменио адресу Ваше е-поште на %2$s.",
+    "Your email address on %s was changed." : "Адреса Ваше е-поште на %s је измењена.",
+    "Your email address on %s was changed by an administrator." : "Администратор на %s је изменио адресу Ваше е-поште.",
+    "Email address changed for %s" : "Адреса е-поште на %s промењена",
+    "The new email address is %s" : "Адреса е-поште је сад %s",
+    "Email address for %1$s changed on %2$s" : "Адреса е-поште за %1$s промењена на %2$s",
+    "Welcome aboard" : "Добродошли",
+    "Welcome aboard %s" : "Добродошли %s",
+    "You now have an %s account, you can add, protect, and share your data." : "Сада имате %s налог, можете додавати, штитити и делити Ваше податке.",
+    "Your username is: %s" : "Ваше корисничко име је: %s",
+    "Set your password" : "Поставите лозинку",
+    "Go to %s" : "Иди на %s",
+    "Install Client" : "Инсталирајте клијенте",
     "Your %s account was created" : "Ваш %s налог је направљен",
+    "Password confirmation is required" : "Потребна је потврда лозинке",
     "Couldn't remove app." : "Не могу да уклоним апликацију.",
     "Couldn't update app." : "Не могу да ажурирам апликацију.",
+    "Are you really sure you want add {domain} as trusted domain?" : "Да ли заиста желите да додате {domain} као поуздан домен?",
     "Add trusted domain" : "Додај поуздан домен",
     "Migration in progress. Please wait until the migration is finished" : "Пресељење је у току. Сачекајте док се не заврши",
     "Migration started …" : "Пресељење покренуто...",
+    "Not saved" : "Несачувано",
+    "Sending…" : "Шаљем…",
     "Email sent" : "Порука је послата",
     "Official" : "Званичне",
     "All" : "Све",
     "Update to %s" : "Ажурирај на %s",
     "No apps found for your version" : "Нема апликација за вашу верзију",
+    "The app will be downloaded from the app store" : "Апликација ће бити скинута са продавнице",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Званичне апликације су развијене за и од стране заједнице. Нуде главне функционалности и спремне су за продукциону употребу.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрене апликације су развили проверени програмери и апликације су прошле основне безбедносне провере. Оне се активно одржавају у репозиторијуму за апликације отвореног кода и њихови одржаватељи сматрају да су стабилне за уобичајену употребу.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ова апликација није проверена по питању безбедности и нова је или зна да буде нестабилна. Инсталирате је на сопствену одговорност.",
+    "Disabling app …" : "Искључујем апликацију …",
     "Error while disabling app" : "Грешка при искључивању апликације",
     "Disable" : "Искључи",
     "Enable" : "Укључи",
+    "Enabling app …" : "Укључујем апликацију …",
     "Error while enabling app" : "Грешка при укључивању апликације",
+    "Error: This app can not be enabled because it makes the server unstable" : "Грешка: ова апликација не може да се укључи јер је због ње цео сервер нестабилан",
+    "Error: Could not disable broken app" : "Грешка: Не могу да искључим покварену апликацију",
+    "Error while disabling broken app" : "Грешка приликом искључивања покварене апликације",
     "Updating...." : "Ажурирам…",
     "Error while updating app" : "Грешка при ажурирању апликације",
     "Updated" : "Ажурирано",
